#!/usr/bin/env ruby
# = Synopsys
#
# This module is used to configure and dradis client.
#
# = Usage
# 
#   ruby launcher.rb [ -v | --version ]
#   
#   -v | --version: display version informaiton.
#
# = License
# 
# This file may be used under the terms of the GNU General Public
# License version 2.0 as published by the Free Software Foundation
# and appearing in the file LICENSE.txt included in the packaging of
# this file.
#

# standard library modules
require 'yaml'

# custom modules
require 'ui/wx/launcher/frame'

# load the config parser from dradis client
# ------------------------------------------------------------------------
$logger.debug{ "Loading dradis client configuration from: conf/dradis.xml" }
require 'core/config'

username, password, host, port = $config.get_option(:restful_server).scan(/https:\/\/([^:@]*):?([^:@]*)@?(.*):(.*)\//).first
refresh = $config.get_option(:ui_refresh).to_i / 1000 
client_conf = { :server_ip => host,
                :server_port => port,
                :refresh => refresh,
                :username => username,
                :password => password
                }


# print the app banner
puts Core::VERSION::string()

# run the wxWidgets interface
Wx::App.run do
  self.app_name = 'launcher'
  frame = Core::MiniFrame.new(nil, Core::VERSION::string()) 
  frame.fill_info( client_conf )
  frame.show()
end
